.. _datasets:

===========
Datasets
===========

.. include:: ../../../QuadratiK/datasets/data/wireless_localization_dataset.rst
.. include:: ../../../QuadratiK/datasets/data/wisconsin_breast_cancer_dataset.rst
.. include:: ../../../QuadratiK/datasets/data/wine_dataset.rst
